@@ -458,7 +458,7 @@ class Insight_Definition:
 
         new_qc = self.create_qc(dataset_slug, fields)
 
-        url = self.smart_insight_url+"composed_queries/{}".format(qc_id)
+        url = self.smart_insight_url+"/composed_queries/{}".format(qc_id)
 
         body = {
             "smartQueryId": new_qc["id"]
